layout: recent
title:  "Home"
summary: "Introduce yourself"

## Quick started

Now put your markdown (`*.md`) files to the `pages` folder then the magic will be happen.

Don't forget add the metas at the first line of your files.

```markdown
title: "The title text of your article"
summary: "The summary of your article"

Here is your article body
```

If you want to write your blog now you can put the markdown files to `posts` folder.

Run the command in your terminal window when you complete your writing:

```
$ freezes build
```

Then copy all files in `builds` folder to your web server to deploy your static website.

## Useful links

- [Freezes](http://freezes.dotnetage.com)
- [Freezes@github](https://github.com/dotnetage/freezes)
- [Freezes@pypi](https://pypi.python.org/pypi/Freezes)